#!/usr/bin/python3

import socket
import sys
import threading

def server(Maximum_Number_Connections):

    serversocket = socket.socket(
                socket.AF_INET, socket.SOCK_STREAM)

    host = socket.gethostname()

    port = int(input("Please enter the communication port number(0~65535):"))

    serversocket.bind((host, port))

    serversocket.listen(Maximum_Number_Connections)

    while True:
        try:
            clientsocket,addr = serversocket.accept()      

            print("The connection is successful\nIn: %s" % str(addr))
            
            msg="The connection is successful\nIn: %s" % str(addr) + "\r"
            clientsocket.send(msg.encode('utf-8'))

            while True:
                msg = input("Enter the text:") + "\r"
                clientsocket.send(msg.encode('utf-8'))
                if msg == "QUIT\r":
                    print("You have interrupted this communication")
                    clientsocket.close()
                    exit()
        except ConnectionResetError:
            print("Error ConnectionResetError was reported, possibly because the remote host forced down an existing connection")
            exit()
        except ConnectionRefusedError:
            print("Error ConnectionRefusedError was reported, possibly because the target computer actively rejected it")
            exit()
        except ConnectionAbortedError:
            print("Error ConnectionAbortedError was reported, possibly because software on the host aborted an established connection")
            exit()
        except BrokenPipeError:
            print("BrokenPipeError was reported")
            exit()

def start(MaxNumCon=5):
    threading.Thread(target=server(MaxNumCon)).start()


#!/usr/bin/python3

import socket
import sys
import time
import threading
from pyesytime import ALL_IN_ONE

def client(Message_Reception_Size):
	s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)

	host = socket.gethostname()

	port = int(input("请输入通信端口号(0~65535):"))

	try:
		s.connect((host, port))
		while True:
			msg = s.recv(Message_Reception_Size)
			print(msg.decode('utf-8'))

			while True:
				msg = s.recv(Message_Reception_Size)
				if msg.decode('utf-8') != "\r":
					print("在"+ALL_IN_ONE()+"收到消息:\n"+msg.decode('utf-8'))
					if msg.decode('utf-8') == "QUIT\r":
						print("对方结束了本次通信")
						s.close()
						exit()
	except ConnectionResetError:
	    print("报出错误ConnectionResetError，可能是远程主机强制关闭现有连接")
	    exit()
	except ConnectionRefusedError:
	    print("报出错误ConnectionRefusedError，可能是目标计算机积极拒绝")
	    exit()
	except ConnectionAbortedError:
	    print("报出错误ConnectionAbortedError，可能是主机中的软件中止了一个已建立的连接")
	    exit()
	except BrokenPipeError:
	    print("报出错误BrokenPipeError")
	    exit()

def start(MsgRecSize=2048):
    threading.Thread(target=client(MsgRecSize)).start()


import setuptools
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
setuptools.setup(
    name="comspy",
    version="2022.2",
    author="SunnyLi",
    author_email="5327136@qq.com",
    description="A package that uses Python to make communication easier",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/SunnyLi1106/ComsPy",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        "pyesytime",
    ],
    python_requires='>=3',
)


#!/usr/bin/python3

import socket
import sys
import time
import threading
from pyesytime import ALL_IN_ONE

def client(Message_Reception_Size):
	s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)

	host = socket.gethostname()

	port = int(input("Please enter the communication port number(0~65535):"))

	try:
		s.connect((host, port))
		while True:
			msg = s.recv(Message_Reception_Size)
			print(msg.decode('utf-8'))

			while True:
				msg = s.recv(Message_Reception_Size)
				if msg.decode('utf-8') != "\r":
					print("Received at "+ALL_IN_ONE()+":"+msg.decode('utf-8'))
					if msg.decode('utf-8') == "QUIT\r":
						print("The other party broke off this communication")
						s.close()
						exit()
	except ConnectionResetError:
	    print("Error ConnectionResetError was reported, possibly because the remote host forced down an existing connection")
	    exit()
	except ConnectionRefusedError:
	    print("Error ConnectionRefusedError was reported, possibly because the target computer actively rejected it")
	    exit()
	except ConnectionAbortedError:
	    print("Error ConnectionAbortedError was reported, possibly because software on the host aborted an established connection")
	    exit()
	except BrokenPipeError:
	    print("BrokenPipeError was reported")
	    exit()

def start(MsgRecSize=2048):
    threading.Thread(target=client(MsgRecSize)).start()


	




#!/usr/bin/python3
# 文件名：server.py

# 导入 socket、sys 模块
import socket
import sys
import threading

def server(Maximum_Number_Connections):
    # 创建 socket 对象
    serversocket = socket.socket(
                socket.AF_INET, socket.SOCK_STREAM)

    # 获取本地主机名
    host = socket.gethostname()

    port = int(input("请输入通信端口号(0~65535):"))

    # 绑定端口号
    serversocket.bind((host, port))

    # 设置最大连接数，超过后排队
    serversocket.listen(Maximum_Number_Connections)

    while True:
        # 建立客户端连接
        try:
            clientsocket,addr = serversocket.accept()      

            print("连接成功\n地址: %s" % str(addr))
            
            msg="连接成功\n地址: %s" % str(addr) + "\r"
            clientsocket.send(msg.encode('utf-8'))

            while True:
                msg = input("输入内容:") + "\r"
                clientsocket.send(msg.encode('utf-8'))
                if msg == "QUIT\r":
                    print("你中断了本次通信")
                    clientsocket.close()
                    exit()
        except ConnectionResetError:
            print("报出错误ConnectionResetError，可能是远程主机强制关闭现有连接")
            exit()
        except ConnectionRefusedError:
            print("报出错误ConnectionRefusedError，可能是目标计算机积极拒绝")
            exit()
        except ConnectionAbortedError:
            print("报出错误ConnectionAbortedError，可能是主机中的软件中止了一个已建立的连接")
            exit()
        except BrokenPipeError:
            print("报出错误BrokenPipeError")
            exit()

def start(MaxNumCon=5):
    threading.Thread(target=server(MaxNumCon)).start()